@@ -19,7 +19,7 @@ class GdapsPluginMeta:
     author = "Christian Gonzalez"
     author_email = "christian.gonzalez@nerdocs.at"
     category = "GDAPS"
-    visible = False
+    # hidden = True
 
 
 class GdapsConfig(PluginConfig):
